@@ -10,10 +10,10 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Git; # git description: v2.036-6-g4ead133
+package Dist::Zilla::Plugin::Git; # git description: v2.037-4-g9a65480
 # ABSTRACT: update your git repository after release
 
-our $VERSION = '2.037'; # TRIAL
+our $VERSION = '2.038'; # TRIAL
 
 use Dist::Zilla 2.100880;    # Need mvp_multivalue_args in Plugin role
 use namespace::autoclean;
@@ -31,7 +31,7 @@ Dist::Zilla::Plugin::Git - update your git repository after release
 
 =head1 VERSION
 
-version 2.037
+version 2.038
 
 =head1 DESCRIPTION
 
@@ -152,7 +152,7 @@ Jerome Quelin
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen Jérôme Quelin Kent Fredric Yanick Champoux Karen Etheridge Ricardo Signes David Golden Graham Knop Chris Weyl Mike Friedman Your Name Stephen R. Scaffidi Randy Stauner Apocalypse Doherty Barr Brian Phillips Matt Follett Michael Schout Brendan Byrd Nigel Metheringham Olivier Mengué Alessandro Ghedini Tatsuhiko Miyagawa Tuomas Jormola Alexandr Ciornii Harley Pig Jesse Luehrs Geoffrey Broadwell Steinbrunner
+=for stopwords Christopher J. Madsen Jérôme Quelin Kent Fredric Karen Etheridge Yanick Champoux Ricardo Signes David Golden Graham Knop Chris Weyl Mike Friedman Your Name Stephen R. Scaffidi Randy Stauner Apocalypse Doherty Barr Brian Phillips Matt Follett Michael Schout Brendan Byrd Nigel Metheringham Olivier Mengué Alessandro Ghedini Tatsuhiko Miyagawa Tuomas Jormola Alexandr Ciornii Harley Pig Jesse Luehrs Geoffrey Broadwell Steinbrunner
 
 =over 4
 
@@ -170,11 +170,11 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+Yanick Champoux <yanick@babyl.dyndns.org>
 
 =item *
 
